#!/usr/bin/env python
# encoding: utf-8
from __future__ import absolute_import, division, print_function, unicode_literals

import sys
import os.path
from flipper._compat import SafeConfigParser, urlparse

class FileStore(object):
    BOOLEAN_VALUES = {
        'false': False,
        'no': False,
        'true': True,
        'yes': True,
    }

    def __init__(self, module, dsn, **kwds):
        self._dsn = dsn
        self._scp = SafeConfigParser()

        parsed_url = urlparse(dsn)
        filepath = parsed_url.netloc
        if not os.path.isabs(filepath):
            dirname = os.path.dirname(sys.modules.get(module).__file__)
            filepath = os.path.join(dirname, filepath)

        assert self._scp.read(filepath)

    def raw_values(self, app_name, fqdn):
        values = {}
        def parse(v):
            if v.lower() in self.BOOLEAN_VALUES:
                return self.BOOLEAN_VALUES[v.lower()]
            return v

        for k, v in self._scp.items(app_name):
            values[k] = parse(v)

        host_specific_section = "%s:%s" % (app_name, fqdn)
        if self._scp.has_section(host_specific_section):
            for k, v in self._scp.items(host_specific_section):
                values[k] = parse(v)

        return values